@@ -2178,17 +2178,12 @@ static Int InitKernel ( StructInitInfo *module )
 */
 static Int InitLibrary ( StructInitInfo *module )
 {
-    Int             i, gvar;
+    Int             gvar;
     Obj             tmp;
 
     /* init filters and functions
        we assign the functions to components of a record "IO"         */
-    for ( i = 0; GVarFuncs[i].name != 0;  i++ ) {
-      gvar = GVarName(GVarFuncs[i].name);
-      AssGVar(gvar,NewFunctionC( GVarFuncs[i].name, GVarFuncs[i].nargs,
-                                 GVarFuncs[i].args, GVarFuncs[i].handler ));
-      MakeReadOnlyGVar(gvar);
-    }
+    InitGVarFuncsFromTable(GVarFuncs);
 
     tmp = NEW_PREC(0);
     /* Constants for the flags: */
